@@ -17,9 +17,11 @@ import netifaces
 from xknx.knxip import (
     DIB,
     HPAI,
+    SRP,
     DIBDeviceInformation,
     DIBServiceFamily,
     DIBSuppSVCFamilies,
+    DIBTypeCode,
     KNXIPBody,
     KNXIPFrame,
     KNXIPServiceType,
@@ -225,9 +227,8 @@ class GatewayScanner:
         logger.debug("Searching on %s / %s", interface, ip_addr)
 
         udp_transport = UDPTransport(
-            self.xknx,
-            (ip_addr, 0),
-            (self.xknx.multicast_group, self.xknx.multicast_port),
+            local_addr=(ip_addr, 0),
+            remote_addr=(self.xknx.multicast_group, self.xknx.multicast_port),
             multicast=True,
         )
 
@@ -246,13 +247,23 @@ class GatewayScanner:
             ip_addr=self.xknx.multicast_group, port=self.xknx.multicast_port
         )
 
-        search_request: KNXIPBody = SearchRequest(
-            self.xknx, discovery_endpoint=discovery_endpoint
-        )
+        search_request: KNXIPBody
         if search_request_type == KNXIPServiceType.SEARCH_REQUEST_EXTENDED:
             search_request = SearchRequestExtended(
-                self.xknx, discovery_endpoint=discovery_endpoint
+                discovery_endpoint=discovery_endpoint,
+                srps=[
+                    SRP.request_device_description(
+                        [
+                            DIBTypeCode.DEVICE_INFO,
+                            DIBTypeCode.SUPP_SVC_FAMILIES,
+                            DIBTypeCode.SECURED_SERVICE_FAMILIES,
+                            DIBTypeCode.TUNNELING_INFO,
+                        ]
+                    )
+                ],
             )
+        else:
+            search_request = SearchRequest(discovery_endpoint=discovery_endpoint)
         udp_transport.send(KNXIPFrame.init_from_body(search_request))
 
     def _response_rec_callback(
