@@ -16,7 +16,6 @@ from .request_response import RequestResponse
 if TYPE_CHECKING:
     from xknx.io.transport import UDPTransport
     from xknx.telegram import IndividualAddress, Telegram
-    from xknx.xknx import XKNX
 
 
 class Tunnelling(RequestResponse):
@@ -26,7 +25,6 @@ class Tunnelling(RequestResponse):
 
     def __init__(
         self,
-        xknx: XKNX,
         transport: UDPTransport,
         data_endpoint: tuple[str, int] | None,
         telegram: Telegram,
@@ -38,7 +36,7 @@ class Tunnelling(RequestResponse):
         self.data_endpoint_addr = data_endpoint
         self.src_address = src_address
 
-        super().__init__(xknx, transport, TunnellingAck)
+        super().__init__(transport, TunnellingAck)
 
         self.telegram = telegram
         self.sequence_counter = sequence_counter
@@ -51,13 +49,11 @@ class Tunnelling(RequestResponse):
     def create_knxipframe(self) -> KNXIPFrame:
         """Create KNX/IP Frame object to be sent to device."""
         cemi = CEMIFrame.init_from_telegram(
-            self.xknx,
             telegram=self.telegram,
             code=CEMIMessageCode.L_DATA_REQ,
             src_addr=self.src_address,
         )
         tunnelling_request = TunnellingRequest(
-            self.xknx,
             communication_channel_id=self.communication_channel_id,
             sequence_counter=self.sequence_counter,
             cemi=cemi,
