@@ -15,7 +15,6 @@ from .util import find_local_ip
 
 if TYPE_CHECKING:
     from xknx.io.transport import KNXIPTransport
-    from xknx.xknx import XKNX
 
 logger = logging.getLogger("xknx.log")
 
@@ -23,7 +22,6 @@ DESCRIPTION_TIMEOUT: Final = 2
 
 
 async def request_description(
-    xknx: XKNX,
     gateway_ip: str,
     gateway_port: int = DEFAULT_MCAST_PORT,
     local_ip: str | None = None,
@@ -33,7 +31,6 @@ async def request_description(
     """Set up a UDP transport to request a description from a KNXnet/IP device."""
     _local_ip = local_ip or find_local_ip(gateway_ip)
     transport = UDPTransport(
-        xknx,
         local_addr=(_local_ip, local_port),
         remote_addr=(gateway_ip, gateway_port),
         multicast=False,
@@ -52,8 +49,7 @@ async def request_description(
         local_hpai = HPAI(*local_addr)
 
     description_query = DescriptionQuery(
-        xknx,
-        transport,
+        transport=transport,
         local_hpai=local_hpai,
     )
     await description_query.start()
@@ -64,9 +60,12 @@ async def request_description(
 class DescriptionQuery:
     """Class to send a DescriptionRequest and wait for DescriptionResponse."""
 
-    def __init__(self, xknx: XKNX, transport: KNXIPTransport, local_hpai: HPAI):
+    def __init__(
+        self,
+        transport: KNXIPTransport,
+        local_hpai: HPAI,
+    ) -> None:
         """Initialize Description class."""
-        self.xknx = xknx
         self.transport = transport
         self.local_hpai = local_hpai
 
@@ -75,10 +74,7 @@ class DescriptionQuery:
 
     def create_knxipframe(self) -> KNXIPFrame:
         """Create KNX/IP Frame object to be sent to device."""
-        description_request = DescriptionRequest(
-            self.xknx,
-            control_endpoint=self.local_hpai,
-        )
+        description_request = DescriptionRequest(control_endpoint=self.local_hpai)
         return KNXIPFrame.init_from_body(description_request)
 
     async def start(self) -> None:
