@@ -3,14 +3,11 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 import logging
-from typing import TYPE_CHECKING, ClassVar, cast
+from typing import ClassVar, cast
 
 from .error_code import ErrorCode
 from .knxip_enum import KNXIPServiceType
 
-if TYPE_CHECKING:
-    from xknx.xknx import XKNX
-
 logger = logging.getLogger("xknx.log")
 
 
@@ -19,10 +16,6 @@ class KNXIPBody(ABC):
 
     SERVICE_TYPE: ClassVar[KNXIPServiceType] = cast(KNXIPServiceType, None)
 
-    def __init__(self, xknx: XKNX):
-        """Initialize KNXIPBody object."""
-        self.xknx = xknx
-
     @abstractmethod
     def calculated_length(self) -> int:
         """Get length of KNX/IP body."""
