@@ -5,17 +5,12 @@ Connectionstate requests are used to determine if a tunnel connection is still a
 """
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
 from xknx.exceptions import CouldNotParseKNXIP
 
 from .body import KNXIPBody
 from .hpai import HPAI
 from .knxip_enum import KNXIPServiceType
 
-if TYPE_CHECKING:
-    from xknx.xknx import XKNX
-
 
 class ConnectionStateRequest(KNXIPBody):
     """Representation of a KNX Connection State Request."""
@@ -24,12 +19,10 @@ class ConnectionStateRequest(KNXIPBody):
 
     def __init__(
         self,
-        xknx: XKNX,
         communication_channel_id: int = 1,
         control_endpoint: HPAI = HPAI(),
     ):
         """Initialize ConnectionStateRequest object."""
-        super().__init__(xknx)
         self.communication_channel_id = communication_channel_id
         self.control_endpoint = control_endpoint
 
