@@ -6,24 +6,18 @@ of the KNXnet/IP Server to obtain a self-description of the KNXnet/IP Server dev
 """
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
 from .body import KNXIPBody
 from .hpai import HPAI
 from .knxip_enum import KNXIPServiceType
 
-if TYPE_CHECKING:
-    from xknx.xknx import XKNX
-
 
 class DescriptionRequest(KNXIPBody):
     """Representation of a KNX Descriptoin Request."""
 
     SERVICE_TYPE = KNXIPServiceType.DESCRIPTION_REQUEST
 
-    def __init__(self, xknx: XKNX, control_endpoint: HPAI = HPAI()):
+    def __init__(self, control_endpoint: HPAI = HPAI()):
         """Initialize SearchRequest object."""
-        super().__init__(xknx)
         self.control_endpoint = control_endpoint
 
     def calculated_length(self) -> int:
