@@ -8,25 +8,19 @@ a search response and one device supporting multiple KNX connections may send mu
 """
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
 from .body import KNXIPBody
 from .dib import DIB, DIBDeviceInformation
 from .hpai import HPAI
 from .knxip_enum import KNXIPServiceType
 
-if TYPE_CHECKING:
-    from xknx.xknx import XKNX
-
 
 class SearchResponse(KNXIPBody):
     """Representation of a KNX Search Response."""
 
     SERVICE_TYPE = KNXIPServiceType.SEARCH_RESPONSE
 
-    def __init__(self, xknx: XKNX, control_endpoint: HPAI = HPAI()):
+    def __init__(self, control_endpoint: HPAI = HPAI()):
         """Initialize SearchResponse object."""
-        super().__init__(xknx)
         self.control_endpoint = control_endpoint
         self.dibs: list[DIB] = []
 
