@@ -16,12 +16,12 @@ from xknx.dpt import (
     DPTHVACContrMode,
     DPTHVACMode,
 )
-from xknx.dpt.dpt_hvac_mode import HVACControllerMode, HVACModeType, HVACOperationMode
+from xknx.dpt.dpt_hvac_mode import HVACControllerMode, HVACModeT, HVACOperationMode
 from xknx.exceptions import ConversionError, CouldNotParseTelegram
 
 from .remote_value import (
     AsyncCallbackType,
-    DPTPayloadType,
+    DPTPayloadT,
     GroupAddressesType,
     RemoteValue,
 )
@@ -30,13 +30,13 @@ if TYPE_CHECKING:
     from xknx.xknx import XKNX
 
 
-class RemoteValueClimateModeBase(RemoteValue[DPTPayloadType, Optional[HVACModeType]]):
+class RemoteValueClimateModeBase(RemoteValue[DPTPayloadT, Optional[HVACModeT]]):
     """Base class for binary climate mode remote values."""
 
     @abstractmethod
     def supported_operation_modes(
         self,
-    ) -> list[HVACModeType]:
+    ) -> list[HVACModeT]:
         """Return a list of all supported operation modes."""
 
 
@@ -126,8 +126,7 @@ class RemoteValueControllerMode(
             after_update_cb=after_update_cb,
         )
 
-    @staticmethod
-    def supported_operation_modes() -> list[HVACControllerMode]:
+    def supported_operation_modes(self) -> list[HVACControllerMode]:
         """Return a list of all supported operation modes."""
         return list(DPTHVACContrMode.SUPPORTED_MODES.values())
 
@@ -137,13 +136,11 @@ class RemoteValueControllerMode(
             return payload
         raise CouldNotParseTelegram("Payload invalid", payload=str(payload))
 
-    @staticmethod
-    def to_knx(value: Any) -> DPTArray:
+    def to_knx(self, value: Any) -> DPTArray:
         """Convert value to payload."""
         return DPTArray(DPTHVACContrMode.to_knx(value))
 
-    @staticmethod
-    def from_knx(payload: DPTArray) -> HVACControllerMode | None:
+    def from_knx(self, payload: DPTArray) -> HVACControllerMode | None:
         """Convert current payload to value."""
         return DPTHVACContrMode.from_knx(payload.value)
 
@@ -208,8 +205,7 @@ class RemoteValueBinaryOperationMode(
             feature_name=self.feature_name,
         )
 
-    @staticmethod
-    def supported_operation_modes() -> list[HVACOperationMode]:
+    def supported_operation_modes(self) -> list[HVACOperationMode]:
         """Return a list of the configured operation mode."""
         return [
             HVACOperationMode.COMFORT,
@@ -218,7 +214,7 @@ class RemoteValueBinaryOperationMode(
             HVACOperationMode.STANDBY,
         ]
 
-    def from_knx(self, payload: DPTPayloadType) -> HVACOperationMode | None:
+    def from_knx(self, payload: DPTPayloadT) -> HVACOperationMode | None:
         """Convert current payload to value."""
         if payload == DPTBinary(1):
             return self.operation_mode
@@ -280,8 +276,7 @@ class RemoteValueBinaryHeatCool(
             return payload
         raise CouldNotParseTelegram("Payload invalid", payload=str(payload))
 
-    @staticmethod
-    def supported_operation_modes() -> list[HVACControllerMode]:
+    def supported_operation_modes(self) -> list[HVACControllerMode]:
         """Return a list of the configured operation mode."""
         return [HVACControllerMode.HEAT, HVACControllerMode.COOL]
 
@@ -297,7 +292,7 @@ class RemoteValueBinaryHeatCool(
             feature_name=self.feature_name,
         )
 
-    def from_knx(self, payload: DPTPayloadType) -> HVACControllerMode | None:
+    def from_knx(self, payload: DPTPayloadT) -> HVACControllerMode | None:
         """Convert current payload to value."""
         if payload == DPTBinary(1):
             return self.controller_mode
