@@ -17,9 +17,9 @@ from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
 from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
 
+from xknx.exceptions.exception import InvalidSignature
 from xknx.telegram import GroupAddress, IndividualAddress
 
-from ..exceptions.exception import InvalidSignature
 from .util import sha256_hash
 
 
