@@ -25,7 +25,7 @@ from xknx.io import (
     KNXIPInterface,
     knx_interface_factory,
 )
-from xknx.telegram import GroupAddressType, IndividualAddress, Telegram
+from xknx.telegram import GroupAddress, GroupAddressType, IndividualAddress, Telegram
 
 from .__version__ import __version__ as VERSION
 
@@ -64,7 +64,6 @@ class XKNX:
         self.task_registry = TaskRegistry(self)
         self.knxip_interface: KNXIPInterface | None = None
         self.started = asyncio.Event()
-        self.address_format = address_format
         self.own_address = IndividualAddress(own_address)
         self.rate_limit = rate_limit
         self.multicast_group = multicast_group
@@ -74,6 +73,7 @@ class XKNX:
         self.version = VERSION
         self.current_address = IndividualAddress(0)
 
+        GroupAddress.address_format = address_format  # for global string representation
         if log_directory is not None:
             self.setup_logging(log_directory)
 
@@ -115,7 +115,7 @@ class XKNX:
         """Start XKNX module. Connect to KNX/IP devices and start state updater."""
         if self.connection_config.threaded:
             await self.connection_manager.register_loop()
-        self.task_registry.start()
+            await self.task_registry.register_loop()
         self.knxip_interface = knx_interface_factory(
             xknx=self,
             connection_config=self.connection_config,
@@ -128,6 +128,7 @@ class XKNX:
         await self.knxip_interface.start()
         await self.telegram_queue.start()
         self.state_updater.start()
+        self.task_registry.start()
         self.started.set()
         if self.daemon_mode:
             await self.loop_until_sigint()
